@@ -11,7 +11,7 @@ pe_event_vtbl event_vtbl, ioevent_vtbl;
 static void pe_anyevent_init(pe_event *ev, pe_watcher *wa) {
     assert(wa);
     ev->up = wa;
-    ++wa->event_counter;
+    ++wa->refcnt;
     ev->mysv = 0;
     PE_RING_INIT(&ev->peer, ev);
     PE_RING_UNSHIFT(&ev->peer, &wa->events);
@@ -36,7 +36,7 @@ static void pe_anyevent_dtor(pe_event *ev) {
     ev->callback = 0;
     PE_RING_DETACH(&ev->peer);
     PE_RING_DETACH(&ev->que);
-    --wa->event_counter;
+    --wa->refcnt;
     if (WaCANDESTROY(wa)) /* running */
 	(*wa->vtbl->dtor)(wa);
 }
@@ -148,8 +148,13 @@ static void pe_event_postCB(pe_cbframe *fp) {
     pe_event *ev = fp->ev;
     pe_watcher *wa = ev->up;
     --CurCBFrame;
-    if (WaACTIVE(wa) && WaINVOKE1(wa) && WaREPEAT(wa))
-	pe_watcher_on(wa, 1);
+    if (WaACTIVE(wa) && WaINVOKE1(wa) && WaREPEAT(wa)) {
+	char *excuse = pe_watcher_on(wa, 1);
+	if (SvIV(DebugLevel) && excuse) {
+	    STRLEN n_a;
+	    warn("Event: can't restart '%s' %s", SvPV(wa->desc,n_a), excuse);
+	}
+    }
     if (Estat.on) {
 	if (fp->stats) {
 	    Estat.scrub(fp->stats, wa);
