@@ -49,8 +49,10 @@ static void pe_signal_dtor(pe_watcher *ev) {
 static char *pe_signal_start(pe_watcher *_ev, int repeat) {
     pe_signal *ev = (pe_signal*) _ev;
     int sig = ev->signal;
+    if (!_ev->callback)
+	return "without callback";
     if (sig == 0)
-	return "no signal";
+	return "without signal";
     if (PE_RING_EMPTY(&Sigring[sig]))
 	rsignal(sig, process_sighandler);
     PE_RING_UNSHIFT(&ev->sring, &Sigring[sig]);
@@ -81,9 +83,17 @@ WKEYMETH(_signal_signal) {
 	    croak("Unrecognized signal '%s'", SvPV(nval, n_a));
 	if (!PE_SIGVALID(sig))
 	    croak("Signal '%s' cannot be caught", SvPV(nval, n_a));
+	/* factor XXX */
 	if (active) pe_watcher_off(ev);
 	sg->signal = sig;
-	if (active) pe_watcher_on(ev, 0);
+	if (active) {
+	    char *excuse = pe_watcher_on(ev, 0);
+	    if (SvIV(DebugLevel) && excuse) {
+		STRLEN n_a;
+		warn("Event: can't restart '%s' %s",
+		     SvPV(ev->desc, n_a), excuse);
+	    }
+	}
     }
 }
 
