@@ -127,9 +127,14 @@ static void pe_var_stop(pe_watcher *_ev) {
 }
 
 static void _var_restart(pe_watcher *ev) {
+    char *excuse;
     if (!WaPOLLING(ev)) return;
     pe_watcher_off(ev);
-    pe_watcher_on(ev, 0);
+    excuse = pe_watcher_on(ev, 0);
+    if (SvIV(DebugLevel) && excuse) {
+	STRLEN n_a;
+	warn("Event: can't restart '%s' %s", SvPV(ev->desc, n_a), excuse);
+    }
 }
 
 WKEYMETH(_var_events) {
@@ -155,9 +160,19 @@ WKEYMETH(_var_variable) {
 	int active = WaPOLLING(ev);
 	if (!SvROK(nval))
 	    croak("Expecting a reference");
+	if (SvTYPE(SvRV(nval)) > SVt_PVMG)
+	    croak("Var watchers can only watch plain vanilla scalars");
+	/* factor XXX */
 	if (active) pe_watcher_off(ev);
 	vp->variable = SvREFCNT_inc(nval);
-	if (active) pe_watcher_on(ev, 0);
+	if (active) {
+	    char *excuse = pe_watcher_on(ev, 0);
+	    if (SvIV(DebugLevel) && excuse) {
+		STRLEN n_a;
+		warn("Event: can't restart '%s' %s",
+		     SvPV(ev->desc,n_a), excuse);
+	    }
+	}
 	SvREFCNT_dec(old);
     }
 }
